Django Ditto: Documentation — Django Ditto 0.4.0 documentation

# Django Ditto: Documentation

A collection of Django apps for copying things from Flickr, Twitter and Pinboard, and displaying them on your Django site.

- Introduction
  - Services covered
  - What Ditto includes
- Installation
  - Pillow
  - Install django-ditto
  - Add to INSTALLED_APPS
  - Add to context processors
  - Add to urls.py
  - Settings
  - Set up each service

Services supported

- Flickr
  - Set-up
  - Models
  - Managers
  - Template tags
  - Management commands
- Last.fm
  - Set-up
  - Models
  - Managers
  - Template tags
  - Management commands
- Pinboard
  - Set-up
  - Models
  - Managers
  - Template tags
  - Management commands
- Twitter
  - Set-up
  - Models
  - Managers
  - Template tags
  - Management commands

For Developers

- Development
  - Tests
  - Other notes for development

Elsewhere

- Django Ditto on GitHub
- Django Ditto on PyPI